@@ -12,5 +12,13 @@ test_that("Printing summaries", {
 
     expect_equal_to_reference(capture.output(print(res)),
                               file = "rds/print2.rds")
+
+    y <- x
+    y$contacts <- y$contacts[1:10, ]
+    y <- thin(y)
+    y$contacts$from[6:9] <- NA
+    y$contacts$to[1]     <- NA
+   expect_output(print(summary(y)), "number missing 'from': 4") 
+   expect_output(print(summary(y)), "number missing 'to': 1") 
     
 })
